History
=======

0.6.0 (2019-08-12)
------------------
- Added Abrahamson, Gregor, Addo (2014)
- Added Abrahamson & Gulerce (2011)
- Added conditional mean spectra models.
- Added Scenario objects.
- Added typing for all classes.

0.4.0 (2016-04-08)
------------------

-  Added Hermkes et al. (2014).
-  Improved documentation.
-  Added Baker & Jayaram (2008), Kishida (2017)

.. _section-1:

0.3.2 (2016-03-30)
------------------

-  Nothing changed yet.

.. _section-2:

0.3.1 (2016-03-30)
------------------

-  First release on PyPI.
